@@ -136,12 +136,12 @@ QalculateEditDataSetDialog::QalculateEditDataSetDialog(TQWidget *parent, const c
 	grid->addItem(new TQSpacerItem(5, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
 
 
-	connect(namesButton, SIGNAL(clicked()), this, SLOT(editNames()));
-	connect(nameEdit, SIGNAL(textChanged(const TQString&)), this, SLOT(nameChanged(const TQString&)));
-	connect(newPropertyButton, SIGNAL(clicked()), this, SLOT(newProperty()));
-	connect(editPropertyButton, SIGNAL(clicked()), this, SLOT(editProperty()));
-	connect(deletePropertyButton, SIGNAL(clicked()), this, SLOT(deleteProperty()));
-	connect(propertiesView, SIGNAL(selectionChanged()), this, SLOT(propertySelectionChanged()));
+	connect(namesButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(editNames()));
+	connect(nameEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(nameChanged(const TQString&)));
+	connect(newPropertyButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(newProperty()));
+	connect(editPropertyButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(editProperty()));
+	connect(deletePropertyButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(deleteProperty()));
+	connect(propertiesView, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(propertySelectionChanged()));
 	
 }
 
@@ -484,7 +484,7 @@ QalculateEditDataPropertyDialog::QalculateEditDataPropertyDialog(TQWidget *paren
 	unitEdit = new KLineEdit(mainWidget());
 	grid->addWidget(unitEdit, 9, 1);
 
-	connect(namesButton, SIGNAL(clicked()), this, SLOT(editNames()));
+	connect(namesButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(editNames()));
 
 }
 
@@ -638,11 +638,11 @@ QalculateEditDataPropertyNamesDialog::QalculateEditDataPropertyNamesDialog(TQWid
 	buttonClose->setDefault(true);
 	buttonLayout->addWidget(buttonClose);
 
-	connect(namesView, SIGNAL(selectionChanged()), this, SLOT(nameSelectionChanged()));
-	connect(buttonClose, SIGNAL(clicked()), this, SLOT(accept()));
-	connect(newButton, SIGNAL(clicked()), this, SLOT(newName()));
-	connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteName()));
-	connect(namesView, SIGNAL(clicked(TQListViewItem*, const TQPoint&, int)), this, SLOT(itemClicked(TQListViewItem*, const TQPoint&, int)));
+	connect(namesView, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(nameSelectionChanged()));
+	connect(buttonClose, TQ_SIGNAL(clicked()), this, TQ_SLOT(accept()));
+	connect(newButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(newName()));
+	connect(deleteButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(deleteName()));
+	connect(namesView, TQ_SIGNAL(clicked(TQListViewItem*, const TQPoint&, int)), this, TQ_SLOT(itemClicked(TQListViewItem*, const TQPoint&, int)));
 
 }
 
